@@ -54,41 +54,27 @@ GLUT::glutInit (JArray< ::java::lang::String *> *argArray)
 	JvInitClass(&GLUT::class$);
 
 	int argc = JvGetArrayLength(argArray)+1;
-	int argc_backup = argc;
-	char** argv = (char**)malloc(sizeof(char*) * argc);
-	char** argv_backup = (char**)malloc(sizeof(char*) * argc);
-	if (argv == NULL || argv_backup == NULL)
-	{
-		fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-		abort();
-	}
+	char** argv = (char**)JvMalloc(sizeof(char*) * argc);
 	argv[0] = "glut4gcj";
 	String** args = elements(argArray);
 	for (int i = 0;i < argArray->length;i++)
 	{
 		jbyteArray byteArray = args[i]->getBytes();
 		jbyte* bytes = elements(byteArray);
-		char* buffer = (char*)malloc(sizeof(char) * (byteArray->length+1));
-		if(buffer == NULL);
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
+		char* buffer = (char*)JvMalloc(sizeof(char) * (byteArray->length+1));
 		memcpy(buffer, bytes, byteArray->length);
 		buffer[byteArray->length] = '\0';
-		argv[i] = buffer;
-		argv_backup[i] = buffer;
+		argv[i+1] = buffer;
 	}
-//	for (int i = 0;i < argc;i++) printf("argv[%d] : %s\n", i, argv[0]);
+//	printf("argc : %d\n", argc);
+//	for (int i = 0;i < argc;i++) printf("argv[%d] : %s\n", i, argv[i]);
 
 	::glutInit(&argc, argv);
+	
+//	printf("argc : %d\n", argc);
+//	for (int i = 0;i < argc;i++) printf("argv[%d] : %s\n", i, argv[i]);
 
-	jstringArray result = JvConvertArgv(argc, (const char**)argv);
-
-	for (int i = 1;i < argc_backup;i++) free(argv_backup[i]);
-	free(argv_backup);
-	free(argv);
-
+	jstringArray result = JvConvertArgv(argc-1, (const char**)(argv+1));
 
 	return result;
 }
@@ -396,15 +382,12 @@ GLUT::glutCreateMenu (MenuFunc* func)
 	{
 		int newLength = menuFuncsLength * 2;
 		if (menuID >= newLength) newLength = menuID * 2 + 2;
-		MenuFunc** newFuncs = (MenuFunc**)malloc(sizeof(MenuFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
+//		menuFuncs = (MenuFunc**)JvRealloc(menuFuncs, sizeof(MenuFunc*) * newLength);  
+//		menuFuncsLength = newLength;
 		
+		MenuFunc** newFuncs = (MenuFunc**)JvMalloc(sizeof(MenuFunc*) * newLength);
 		memcpy(newFuncs, menuFuncs, sizeof(MenuFunc*) * menuFuncsLength);
-		free(menuFuncs);
+		JvFree(menuFuncs);
 		menuFuncs = newFuncs;
 		menuFuncsLength = newLength;
 	}
@@ -542,15 +525,9 @@ GLUT::glutDisplayFunc (::glut4gcj::DisplayFunc *func)
 	{
 		int newLength = displayFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		DisplayFunc** newFuncs = (DisplayFunc**)malloc(sizeof(DisplayFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		DisplayFunc** newFuncs = (DisplayFunc**)JvMalloc(sizeof(DisplayFunc*) * newLength);  
 		memcpy(newFuncs, displayFuncs, sizeof(DisplayFunc*) * displayFuncsLength);
-		free(displayFuncs);
+		JvFree(displayFuncs);
 		displayFuncs = newFuncs;
 		displayFuncsLength = newLength;
 	}
@@ -584,15 +561,9 @@ GLUT::glutReshapeFunc (::glut4gcj::ReshapeFunc *func)
 	{
 		int newLength = reshapeFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		ReshapeFunc** newFuncs = (ReshapeFunc**)malloc(sizeof(ReshapeFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		ReshapeFunc** newFuncs = (ReshapeFunc**)JvMalloc(sizeof(ReshapeFunc*) * newLength);  
 		memcpy(newFuncs, reshapeFuncs, sizeof(ReshapeFunc*) * reshapeFuncsLength);
-		free(reshapeFuncs);
+		JvFree(reshapeFuncs);
 		reshapeFuncs = newFuncs;
 		reshapeFuncsLength = newLength;
 	}
@@ -632,15 +603,9 @@ GLUT::glutKeyboardFunc (::glut4gcj::KeyboardFunc *func)
 	{
 		int newLength = keyboardFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		KeyboardFunc** newFuncs = (KeyboardFunc**)malloc(sizeof(KeyboardFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		KeyboardFunc** newFuncs = (KeyboardFunc**)JvMalloc(sizeof(KeyboardFunc*) * newLength);  
 		memcpy(newFuncs, keyboardFuncs, sizeof(KeyboardFunc*) * keyboardFuncsLength);
-		free(keyboardFuncs);
+		JvFree(keyboardFuncs);
 		keyboardFuncs = newFuncs;
 		keyboardFuncsLength = newLength;
 	}
@@ -680,15 +645,9 @@ GLUT::glutMouseFunc (::glut4gcj::MouseFunc *func)
 	{
 		int newLength = mouseFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		MouseFunc** newFuncs = (MouseFunc**)malloc(sizeof(MouseFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		MouseFunc** newFuncs = (MouseFunc**)JvMalloc(sizeof(MouseFunc*) * newLength);  
 		memcpy(newFuncs, mouseFuncs, sizeof(MouseFunc*) * mouseFuncsLength);
-		free(mouseFuncs);
+		JvFree(mouseFuncs);
 		mouseFuncs = newFuncs;
 		mouseFuncsLength = newLength;
 	}
@@ -727,15 +686,9 @@ GLUT::glutMotionFunc (::glut4gcj::MotionFunc *func)
 	{
 		int newLength = motionFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		MotionFunc** newFuncs = (MotionFunc**)malloc(sizeof(MotionFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		MotionFunc** newFuncs = (MotionFunc**)JvMalloc(sizeof(MotionFunc*) * newLength);  
 		memcpy(newFuncs, motionFuncs, sizeof(MotionFunc*) * motionFuncsLength);
-		free(motionFuncs);
+		JvFree(motionFuncs);
 		motionFuncs = newFuncs;
 		motionFuncsLength = newLength;
 	}
@@ -774,15 +727,9 @@ GLUT::glutPassiveMotionFunc (::glut4gcj::PassiveMotionFunc *func)
 	{
 		int newLength = passiveMotionFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		PassiveMotionFunc** newFuncs = (PassiveMotionFunc**)malloc(sizeof(PassiveMotionFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		PassiveMotionFunc** newFuncs = (PassiveMotionFunc**)JvMalloc(sizeof(PassiveMotionFunc*) * newLength);  
 		memcpy(newFuncs, passiveMotionFuncs, sizeof(PassiveMotionFunc*) * passiveMotionFuncsLength);
-		free(passiveMotionFuncs);
+		JvFree(passiveMotionFuncs);
 		passiveMotionFuncs = newFuncs;
 		passiveMotionFuncsLength = newLength;
 	}
@@ -822,15 +769,9 @@ GLUT::glutEntryFunc (::glut4gcj::EntryFunc *func)
 	{
 		int newLength = entryFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		EntryFunc** newFuncs = (EntryFunc**)malloc(sizeof(EntryFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		EntryFunc** newFuncs = (EntryFunc**)JvMalloc(sizeof(EntryFunc*) * newLength);  
 		memcpy(newFuncs, entryFuncs, sizeof(EntryFunc*) * entryFuncsLength);
-		free(entryFuncs);
+		JvFree(entryFuncs);
 		entryFuncs = newFuncs;
 		entryFuncsLength = newLength;
 	}
@@ -870,15 +811,9 @@ GLUT::glutVisibilityFunc (::glut4gcj::VisibilityFunc *func)
 	{
 		int newLength = visibilityFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		VisibilityFunc** newFuncs = (VisibilityFunc**)malloc(sizeof(VisibilityFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		VisibilityFunc** newFuncs = (VisibilityFunc**)JvMalloc(sizeof(VisibilityFunc*) * newLength);  
 		memcpy(newFuncs, visibilityFuncs, sizeof(VisibilityFunc*) * visibilityFuncsLength);
-		free(visibilityFuncs);
+		JvFree(visibilityFuncs);
 		visibilityFuncs = newFuncs;
 		visibilityFuncsLength = newLength;
 	}
@@ -964,18 +899,12 @@ GLUT::glutTimerFunc (jint msec, ::glut4gcj::TimerFunc *func, jint value)
 		int newLength = timerFuncsLength * 2 + 2;
 //		fprintf(stderr, "Allocate timerFuncs[] and timerValues[]. newLength = %d\n", newLength);
 
-		TimerFunc** newFuncs = (TimerFunc**)malloc(sizeof(TimerFunc*) * newLength);  
-		jint* newValues = (jint*)malloc(sizeof(jint) * newLength);  
-		if(newFuncs == NULL || newValues == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		TimerFunc** newFuncs = (TimerFunc**)JvMalloc(sizeof(TimerFunc*) * newLength);  
+		jint* newValues = (jint*)JvMalloc(sizeof(jint) * newLength);  
 		memcpy(newFuncs, timerFuncs, sizeof(TimerFunc*) * timerFuncsLength);
 		memcpy(newValues, timerValues, sizeof(jint) * timerFuncsLength);
-		free(timerFuncs);
-		free(timerValues);
+		JvFree(timerFuncs);
+		JvFree(timerValues);
 		timerFuncs = newFuncs;
 		timerValues = newValues;
 		timerFuncsLength = newLength;
@@ -1012,15 +941,9 @@ GLUT::glutMenuStateFunc (::glut4gcj::MenuStateFunc *func)
 	{
 		int newLength = menuStateFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		MenuStateFunc** newFuncs = (MenuStateFunc**)malloc(sizeof(MenuStateFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		MenuStateFunc** newFuncs = (MenuStateFunc**)JvMalloc(sizeof(MenuStateFunc*) * newLength);  
 		memcpy(newFuncs, menuStateFuncs, sizeof(MenuStateFunc*) * menuStateFuncsLength);
-		free(menuStateFuncs);
+		JvFree(menuStateFuncs);
 		menuStateFuncs = newFuncs;
 		menuStateFuncsLength = newLength;
 	}
@@ -1061,15 +984,9 @@ GLUT::glutSpecialFunc (::glut4gcj::SpecialFunc *func)
 	{
 		int newLength = specialFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		SpecialFunc** newFuncs = (SpecialFunc**)malloc(sizeof(SpecialFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		SpecialFunc** newFuncs = (SpecialFunc**)JvMalloc(sizeof(SpecialFunc*) * newLength);  
 		memcpy(newFuncs, specialFuncs, sizeof(SpecialFunc*) * specialFuncsLength);
-		free(specialFuncs);
+		JvFree(specialFuncs);
 		specialFuncs = newFuncs;
 		specialFuncsLength = newLength;
 	}
@@ -1112,15 +1029,9 @@ GLUT::glutSpaceballMotionFunc (::glut4gcj::SpaceballMotionFunc *func)
 	{
 		int newLength = spaceballMotionFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		SpaceballMotionFunc** newFuncs = (SpaceballMotionFunc**)malloc(sizeof(SpaceballMotionFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		SpaceballMotionFunc** newFuncs = (SpaceballMotionFunc**)JvMalloc(sizeof(SpaceballMotionFunc*) * newLength);  
 		memcpy(newFuncs, spaceballMotionFuncs, sizeof(SpaceballMotionFunc*) * spaceballMotionFuncsLength);
-		free(spaceballMotionFuncs);
+		JvFree(spaceballMotionFuncs);
 		spaceballMotionFuncs = newFuncs;
 		spaceballMotionFuncsLength = newLength;
 	}
@@ -1162,15 +1073,9 @@ GLUT::glutSpaceballRotateFunc (::glut4gcj::SpaceballRotateFunc *func)
 	{
 		int newLength = spaceballRotateFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		SpaceballRotateFunc** newFuncs = (SpaceballRotateFunc**)malloc(sizeof(SpaceballRotateFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		SpaceballRotateFunc** newFuncs = (SpaceballRotateFunc**)JvMalloc(sizeof(SpaceballRotateFunc*) * newLength);  
 		memcpy(newFuncs, spaceballRotateFuncs, sizeof(SpaceballRotateFunc*) * spaceballRotateFuncsLength);
-		free(spaceballRotateFuncs);
+		JvFree(spaceballRotateFuncs);
 		spaceballRotateFuncs = newFuncs;
 		spaceballRotateFuncsLength = newLength;
 	}
@@ -1213,15 +1118,9 @@ GLUT::glutSpaceballButtonFunc (::glut4gcj::SpaceballButtonFunc *func)
 	{
 		int newLength = spaceballButtonFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		SpaceballButtonFunc** newFuncs = (SpaceballButtonFunc**)malloc(sizeof(SpaceballButtonFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		SpaceballButtonFunc** newFuncs = (SpaceballButtonFunc**)JvMalloc(sizeof(SpaceballButtonFunc*) * newLength);  
 		memcpy(newFuncs, spaceballButtonFuncs, sizeof(SpaceballButtonFunc*) * spaceballButtonFuncsLength);
-		free(spaceballButtonFuncs);
+		JvFree(spaceballButtonFuncs);
 		spaceballButtonFuncs = newFuncs;
 		spaceballButtonFuncsLength = newLength;
 	}
@@ -1264,15 +1163,9 @@ GLUT::glutButtonBoxFunc (::glut4gcj::ButtonBoxFunc *func)
 	{
 		int newLength = buttonBoxFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		ButtonBoxFunc** newFuncs = (ButtonBoxFunc**)malloc(sizeof(ButtonBoxFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		ButtonBoxFunc** newFuncs = (ButtonBoxFunc**)JvMalloc(sizeof(ButtonBoxFunc*) * newLength);  
 		memcpy(newFuncs, buttonBoxFuncs, sizeof(ButtonBoxFunc*) * buttonBoxFuncsLength);
-		free(buttonBoxFuncs);
+		JvFree(buttonBoxFuncs);
 		buttonBoxFuncs = newFuncs;
 		buttonBoxFuncsLength = newLength;
 	}
@@ -1315,15 +1208,9 @@ GLUT::glutDialsFunc (::glut4gcj::DialsFunc *func)
 	{
 		int newLength = dialsFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		DialsFunc** newFuncs = (DialsFunc**)malloc(sizeof(DialsFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		DialsFunc** newFuncs = (DialsFunc**)JvMalloc(sizeof(DialsFunc*) * newLength);  
 		memcpy(newFuncs, dialsFuncs, sizeof(DialsFunc*) * dialsFuncsLength);
-		free(dialsFuncs);
+		JvFree(dialsFuncs);
 		dialsFuncs = newFuncs;
 		dialsFuncsLength = newLength;
 	}
@@ -1365,15 +1252,9 @@ GLUT::glutTabletMotionFunc (::glut4gcj::TabletMotionFunc *func)
 	{
 		int newLength = tabletMotionFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		TabletMotionFunc** newFuncs = (TabletMotionFunc**)malloc(sizeof(TabletMotionFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		TabletMotionFunc** newFuncs = (TabletMotionFunc**)JvMalloc(sizeof(TabletMotionFunc*) * newLength);  
 		memcpy(newFuncs, tabletMotionFuncs, sizeof(TabletMotionFunc*) * tabletMotionFuncsLength);
-		free(tabletMotionFuncs);
+		JvFree(tabletMotionFuncs);
 		tabletMotionFuncs = newFuncs;
 		tabletMotionFuncsLength = newLength;
 	}
@@ -1415,15 +1296,9 @@ GLUT::glutTabletButtonFunc (::glut4gcj::TabletButtonFunc *func)
 	{
 		int newLength = tabletButtonFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		TabletButtonFunc** newFuncs = (TabletButtonFunc**)malloc(sizeof(TabletButtonFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		TabletButtonFunc** newFuncs = (TabletButtonFunc**)JvMalloc(sizeof(TabletButtonFunc*) * newLength);  
 		memcpy(newFuncs, tabletButtonFuncs, sizeof(TabletButtonFunc*) * tabletButtonFuncsLength);
-		free(tabletButtonFuncs);
+		JvFree(tabletButtonFuncs);
 		tabletButtonFuncs = newFuncs;
 		tabletButtonFuncsLength = newLength;
 	}
@@ -1466,15 +1341,9 @@ GLUT::glutMenuStatusFunc (::glut4gcj::MenuStatusFunc *func)
 	{
 		int newLength = menuStatusFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		MenuStatusFunc** newFuncs = (MenuStatusFunc**)malloc(sizeof(MenuStatusFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		MenuStatusFunc** newFuncs = (MenuStatusFunc**)JvMalloc(sizeof(MenuStatusFunc*) * newLength);  
 		memcpy(newFuncs, menuStatusFuncs, sizeof(MenuStatusFunc*) * menuStatusFuncsLength);
-		free(menuStatusFuncs);
+		JvFree(menuStatusFuncs);
 		menuStatusFuncs = newFuncs;
 		menuStatusFuncsLength = newLength;
 	}
@@ -1518,15 +1387,9 @@ GLUT::glutOverlayDisplayFunc (::glut4gcj::OverlayDisplayFunc *func)
 	{
 		int newLength = overlayDisplayFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		OverlayDisplayFunc** newFuncs = (OverlayDisplayFunc**)malloc(sizeof(OverlayDisplayFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		OverlayDisplayFunc** newFuncs = (OverlayDisplayFunc**)JvMalloc(sizeof(OverlayDisplayFunc*) * newLength);  
 		memcpy(newFuncs, overlayDisplayFuncs, sizeof(OverlayDisplayFunc*) * overlayDisplayFuncsLength);
-		free(overlayDisplayFuncs);
+		JvFree(overlayDisplayFuncs);
 		overlayDisplayFuncs = newFuncs;
 		overlayDisplayFuncsLength = newLength;
 	}
@@ -1566,15 +1429,9 @@ GLUT::glutWindowStatusFunc (::glut4gcj::WindowStatusFunc *func)
 	{
 		int newLength = windowStatusFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		WindowStatusFunc** newFuncs = (WindowStatusFunc**)malloc(sizeof(WindowStatusFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		WindowStatusFunc** newFuncs = (WindowStatusFunc**)JvMalloc(sizeof(WindowStatusFunc*) * newLength);  
 		memcpy(newFuncs, windowStatusFuncs, sizeof(WindowStatusFunc*) * windowStatusFuncsLength);
-		free(windowStatusFuncs);
+		JvFree(windowStatusFuncs);
 		windowStatusFuncs = newFuncs;
 		windowStatusFuncsLength = newLength;
 	}
@@ -1613,15 +1470,9 @@ GLUT::glutKeyboardUpFunc (::glut4gcj::KeyboardUpFunc *func)
 	{
 		int newLength = keyboardUpFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		KeyboardUpFunc** newFuncs = (KeyboardUpFunc**)malloc(sizeof(KeyboardUpFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		KeyboardUpFunc** newFuncs = (KeyboardUpFunc**)JvMalloc(sizeof(KeyboardUpFunc*) * newLength);  
 		memcpy(newFuncs, keyboardUpFuncs, sizeof(KeyboardUpFunc*) * keyboardUpFuncsLength);
-		free(keyboardUpFuncs);
+		JvFree(keyboardUpFuncs);
 		keyboardUpFuncs = newFuncs;
 		keyboardUpFuncsLength = newLength;
 	}
@@ -1663,15 +1514,9 @@ GLUT::glutSpecialUpFunc (::glut4gcj::SpecialUpFunc *func)
 	{
 		int newLength = specialUpFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		SpecialUpFunc** newFuncs = (SpecialUpFunc**)malloc(sizeof(SpecialUpFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		SpecialUpFunc** newFuncs = (SpecialUpFunc**)JvMalloc(sizeof(SpecialUpFunc*) * newLength);  
 		memcpy(newFuncs, specialUpFuncs, sizeof(SpecialUpFunc*) * specialUpFuncsLength);
-		free(specialUpFuncs);
+		JvFree(specialUpFuncs);
 		specialUpFuncs = newFuncs;
 		specialUpFuncsLength = newLength;
 	}
@@ -1714,15 +1559,9 @@ GLUT::glutJoystickFunc (::glut4gcj::JoystickFunc *func, jint pollInterval)
 	{
 		int newLength = joystickFuncsLength * 2;
 		if (win >= newLength) newLength = win * 2 + 2;
-		JoystickFunc** newFuncs = (JoystickFunc**)malloc(sizeof(JoystickFunc*) * newLength);  
-		if(newFuncs == NULL)
-		{
-			fprintf(stderr, "%s: %d: malloc() fail.\n", __FILE__, __LINE__);
-			abort();
-		}
-		
+		JoystickFunc** newFuncs = (JoystickFunc**)JvMalloc(sizeof(JoystickFunc*) * newLength);  
 		memcpy(newFuncs, joystickFuncs, sizeof(JoystickFunc*) * joystickFuncsLength);
-		free(joystickFuncs);
+		JvFree(joystickFuncs);
 		joystickFuncs = newFuncs;
 		joystickFuncsLength = newLength;
 	}
