@@ -1,33 +1,31 @@
 import gl4gcj.*;
 import glut4gcj.*;
 import java.util.Random;
-import java.util.HashMap;
 
 class Sprite extends GL
 {
 	private static final int MAX_SPEED = 1;
-	private static final int SIZE = 16;
+	private static final int SIZE = 32;
 	private static final Random random = new Random();
 
 	private int movableW, movableH;
 
-	private int x, y, w, h, dx = 0, dy = 0;
-	private int z_angle = 0;
-	private double brightness = 0.0;
+	private int x, y, hw, hh, dx = 0, dy = 0;
+	private int texture;
 
-	Sprite(int screenW, int screenH)
+	Sprite(int texture, int screenW, int screenH)
 	{
+		this.texture = texture;
+
 		// init size
-		this.w = SIZE;
-		this.h = SIZE;
-		this.movableW = screenW - this.w;
-		this.movableH = screenH - this.h;
+		this.hw = SIZE/2;
+		this.hh = SIZE/2;
+		this.movableW = screenW - SIZE;
+		this.movableH = screenH - SIZE;
 
 		// init location
 		this.x = random.nextInt(movableW);
 		this.y = random.nextInt(movableH);
-		this.z_angle = random.nextInt(360);
-		this.brightness = random.nextDouble() / 2.0 + 0.5;
 
 		// init speed
 		while(dx == 0 && dy == 0)
@@ -37,12 +35,6 @@ class Sprite extends GL
 		}
 	}
 
-	// for Rect interface 
-	public final int getX() { return this.x; }
-	public final int getY() { return this.y; }
-	public final int getW() { return this.w; }
-	public final int getH() { return this.h; }
-
 	public final void move()
 	{
 		x += dx;
@@ -59,25 +51,23 @@ class Sprite extends GL
 			y += dy;
 		}
 
-		z_angle = (z_angle + 4) % 360;
 	}
 
 	public final void draw()
 	{
 		glLoadIdentity();
-		glTranslated(this.getX() + this.getW()/2, this.getY() + this.getH()/2, 0);
-		glRotated(z_angle, 0.0, 0.0, 1.0);
-
-		int hw = this.getW()/2;
-		int hh = this.getH()/2;
-
-		glColor3d(this.brightness, this.brightness, this.brightness);
+		glTranslated(x + hw, y + hh, 0);
 
+		glBindTexture(GL_TEXTURE_2D, this.texture);
 		glBegin(GL_POLYGON);
-		glVertex2i(-hw,  hh);
+		glTexCoord2i(0,  0);
 		glVertex2i(-hw, -hh);
+		glTexCoord2i(1,  0);
 		glVertex2i( hw, -hh);
+		glTexCoord2i(1,  1);
 		glVertex2i( hw,  hh);
+		glTexCoord2i(0,  1);
+		glVertex2i(-hw,  hh);
 		glEnd();
 	}
 }
@@ -85,45 +75,73 @@ class Sprite extends GL
 public class TestSpriteGL extends GLUT 
 	implements DisplayFunc, IdleFunc, KeyboardFunc, ReshapeFunc, TimerFunc
 {
-	private static final int INTERVAL_TIME = 10;
+	private static final int DEFAULT_NUMBER_OF_SPRITE = 100;
+	private static final int INTERVAL_TIME = 1000;
 	private static final int SCREEN_WIDTH = 640;
 	private static final int SCREEN_HEIGHT = 480;
-	private static final int NUMBER_OF_SPRITE = 5000;
 
 	private Sprite[] sprites;
 	private int frames = 0;
+	private StringBuffer buffer = new StringBuffer();
 
-	public TestSpriteGL()
+	public TestSpriteGL(int numberOfSprite)
 	{
-		this.sprites = new Sprite[NUMBER_OF_SPRITE];
-		for (int i = this.sprites.length-1;i >= 0;i--)
-			this.sprites[i] = new Sprite(SCREEN_WIDTH, SCREEN_HEIGHT);
-	}
+		glClearColor(0.0, 0.0, 0.0, 0.0);
+		glEnable(GL_BLEND);
+		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
+		glEnable(GL_TEXTURE_2D);
+		int texture = glGenTexture();
+		glBindTexture(GL_TEXTURE_2D, texture);
+		glTexImage2D(GL_TEXTURE_2D, 0,
+			Icon.FORMAT, Icon.WIDTH, Icon.HEIGHT, 0,
+			Icon.FORMAT, Icon.TYPE, Icon.PIXELS);
+		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
+		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
+		glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+
+		glMatrixMode(GL_MODELVIEW);
+
+		this.sprites = new Sprite[numberOfSprite];
+		for (int i = this.sprites.length-1;i >= 0;i--)
+			this.sprites[i] = new Sprite(texture, SCREEN_WIDTH, SCREEN_HEIGHT);
+	}
 
 	public void reshape(int width, int height)
 	{
 		glViewport(0, 0, width, height);
 		glMatrixMode(GL_PROJECTION);
 		glLoadIdentity();
-		glOrtho(0.0, 640.0, 0.0, 480.0, -10.0, 10.0);
+		glOrtho(0.0, SCREEN_WIDTH, 0.0, SCREEN_HEIGHT, -1.0, 1.0);
 		glMatrixMode(GL_MODELVIEW);
 	}
 
+	void drawSprites()
+	{
+		for (int i = sprites.length-1;i >= 0 ;i--)
+		{
+			this.sprites[i].draw();
+		}
+	}
+
+	void drawMessage()
+	{
+		glPushAttrib(GL_ENABLE_BIT);
+		glDisable(GL_TEXTURE_2D);
+		glDisable(GL_BLEND);
+			glLoadIdentity();
+			glRasterPos2i(0, 0);
+			glBitmap(0, 0, 0, 0, 10, 10, null);
+			glutBitmapCharacter(GLUT_BITMAP_TIMES_ROMAN_24, buffer);
+		glPopAttrib();
+	}
+
 	public void display()
 	{
 		glClear(GL_COLOR_BUFFER_BIT);
 
-		for (int i = sprites.length-1;i >= 0 ;i--)
-		{
-			this.sprites[i].draw();
-		}
-		/*
-		glLoadIdentity();
-		glColor3d(0.0, 0.0, 0.0);
-		glScaled(0.2, 0.2, 1.0);
-		glutStrokeCharacter(GLUT_STROKE_ROMAN, buffer);
-		*/
+		drawSprites();
+		drawMessage();
 
 		glutSwapBuffers();
 	}
@@ -142,13 +160,16 @@ public class TestSpriteGL extends GLUT
 	{
 		double fps = (this.frames * 1000.0)/ INTERVAL_TIME;
 		this.frames = 0;
-		System.out.print(fps);
-		System.out.println(" frames per second");
 
-		System.out.print("Memory : ");
-		System.out.print(Runtime.getRuntime().freeMemory());
-		System.out.print("/");
-		System.out.println(Runtime.getRuntime().totalMemory());
+		this.buffer.delete(0, this.buffer.length());
+		this.buffer.append(fps);
+		this.buffer.append("(fps)");
+		/*
+		this.buffer.append(" Mem : ");
+		this.buffer.append(Runtime.getRuntime().freeMemory());
+		this.buffer.append("/");
+		this.buffer.append(Runtime.getRuntime().totalMemory());
+		*/
 		
 		glutTimerFunc(INTERVAL_TIME, this);
 	}
@@ -168,16 +189,24 @@ public class TestSpriteGL extends GLUT
 
 	public static void main(String[] args)
 	{
-		
 		try
 		{
-			glutInit(args);
+			args = glutInit(args);
 			glutInitWindowSize(SCREEN_WIDTH, SCREEN_HEIGHT);
-//			glutInitDisplayMode(GLUT_RGB);
 			glutInitDisplayMode(GLUT_RGB|GLUT_DOUBLE);
 			glutCreateWindow("TestSpriteGL");
 
-			TestSpriteGL testSprite = new TestSpriteGL();
+			int numberOfSprite = DEFAULT_NUMBER_OF_SPRITE;
+			if (args.length > 0)
+			{
+				try
+				{
+					numberOfSprite = Integer.parseInt(args[0]);
+				}
+				catch (NumberFormatException e) { }
+			}
+
+			TestSpriteGL testSprite = new TestSpriteGL(numberOfSprite);
 			glutDisplayFunc(testSprite);
 			glutReshapeFunc(testSprite);
 			glutKeyboardFunc(testSprite);
@@ -186,7 +215,6 @@ public class TestSpriteGL extends GLUT
 
 			System.gc();
 			glutMainLoop();
-
 		}
 		catch (Exception e)
 		{
